@@ -554,9 +554,9 @@ SEXP fnthlCpp(const List& x, double Q = 0.5, int ng = 0, const IntegerVector& g
         List outl(l);
         for(int j = l; j--; ) {
           outl[j] = out[j];
-          DUPLICATE_ATTRIB(outl[j], x[j]);
+          SHALLOW_DUPLICATE_ATTRIB(outl[j], x[j]);
         }
-        DUPLICATE_ATTRIB(outl, x);
+        SHALLOW_DUPLICATE_ATTRIB(outl, x);
         Rf_setAttrib(outl, R_RowNamesSymbol, Rf_ScalarInteger(1));
         return outl;
       }
@@ -596,7 +596,7 @@ SEXP fnthlCpp(const List& x, double Q = 0.5, int ng = 0, const IntegerVector& g
               nthj[i-1] = (tiesmean && n%2 == 0) ? (*(mid) + *(std::min_element(mid+1, end)))*0.5 : *(mid);
             }
           }
-          DUPLICATE_ATTRIB(nthj, column);
+          SHALLOW_DUPLICATE_ATTRIB(nthj, column);
           out[j] = nthj;
         }
       } else {
@@ -624,11 +624,11 @@ SEXP fnthlCpp(const List& x, double Q = 0.5, int ng = 0, const IntegerVector& g
             std::nth_element(begin, mid, end);
             nthj[i] = (tiesmean && n%2 == 0) ? (*(mid) + *(std::min_element(mid+1, end)))*0.5 : *(mid);
           }
-          DUPLICATE_ATTRIB(nthj, column);
+          SHALLOW_DUPLICATE_ATTRIB(nthj, column);
           out[j] = nthj;
         }
       }
-      DUPLICATE_ATTRIB(out, x);
+      SHALLOW_DUPLICATE_ATTRIB(out, x);
       Rf_setAttrib(out, R_RowNamesSymbol, IntegerVector::create(NA_INTEGER, -ng));
       return out;
     }
@@ -695,9 +695,9 @@ SEXP fnthlCpp(const List& x, double Q = 0.5, int ng = 0, const IntegerVector& g
           List outl(l);
           for(int j = l; j--; ) {
             outl[j] = out[j];
-            DUPLICATE_ATTRIB(outl[j], x[j]);
+            SHALLOW_DUPLICATE_ATTRIB(outl[j], x[j]);
           }
-          DUPLICATE_ATTRIB(outl, x);
+          SHALLOW_DUPLICATE_ATTRIB(outl, x);
           Rf_setAttrib(outl, R_RowNamesSymbol, Rf_ScalarInteger(1));
           return outl;
         }
@@ -763,10 +763,10 @@ SEXP fnthlCpp(const List& x, double Q = 0.5, int ng = 0, const IntegerVector& g
             }
           }
         }
-        DUPLICATE_ATTRIB(nthj, column);
+        SHALLOW_DUPLICATE_ATTRIB(nthj, column);
         out[j] = nthj;
       }
-      DUPLICATE_ATTRIB(out, x);
+      SHALLOW_DUPLICATE_ATTRIB(out, x);
       Rf_setAttrib(out, R_RowNamesSymbol, IntegerVector::create(NA_INTEGER, -ng));
       return out;
     }
