@@ -3,20 +3,20 @@ context("fdiff / D and fgrowth / G")
 # rm(list = ls())
 
 # TODO: test computations on irregular time series and panels
-
+set.seed(101)
 x <- abs(10*rnorm(100))
 xNA <- x
 xNA[sample.int(100, 20)] <- NA
 f <- as.factor(rep(1:10, each = 10))
 t <- as.factor(rep(1:10, 10))
 
-data <- wlddev[wlddev$iso3c %in% c("BLZ","IND","USA","SRB","GRL"), ]
+data <- setRownames(wlddev[wlddev$iso3c %in% c("BLZ","IND","USA","SRB","GRL"), ])
 g <- GRP(droplevels(data$iso3c))
 td <- as.factor(data$year)
 data <- num_vars(data)
 dataNA <- na_insert(data)
-m <- as.matrix(data)
-mNA <- as.matrix(dataNA)
+m <- qM(data)
+mNA <- qM(dataNA)
 mNAc <- mNA
 storage.mode(mNAc) <- "character"
 
@@ -32,7 +32,7 @@ o = order(o)
 od = order(rnorm(length(td)))
 muo = m[od, ]
 datauo = data[od, ]
-guo = as.factor_GRP(g)[od]
+guo = as_factor_GRP(g)[od]
 tduo = td[od]
 t2duo = seq_along(od)[od]
 od = order(od)
@@ -443,8 +443,8 @@ test_that("D.data.frame method is foolproof", {
   expect_error(D(wlddev, 1,1,~iso3c, cols = NULL))
   expect_error(D(wlddev, 1,1,wlddev$iso3c, wlddev$year, cols = NULL))
   expect_error(D(wlddev, 1,1,~iso3c, ~year, cols = NULL))
-  expect_error(D(wlddev, cols = 9:13))
-  expect_error(D(wlddev, 1,1,~iso3c, ~year, cols = 9:13))
+  expect_error(D(wlddev, cols = 9:14))
+  expect_error(D(wlddev, 1,1,~iso3c, ~year, cols = 9:14))
   expect_error(D(wlddev, cols = c("PCGDP","LIFEEX","bla")))
   expect_error(D(wlddev, 1,1,~iso3c, ~year, cols = c("PCGDP","LIFEEX","bla")))
 
@@ -869,8 +869,8 @@ test_that("G.data.frame method is foolproof", {
   expect_error(G(wlddev, 1,1,~iso3c, cols = NULL))
   expect_error(G(wlddev, 1,1,wlddev$iso3c, wlddev$year, cols = NULL))
   expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = NULL))
-  expect_error(G(wlddev, cols = 9:13))
-  expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = 9:13))
+  expect_error(G(wlddev, cols = 9:14))
+  expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = 9:14))
   expect_error(G(wlddev, cols = c("PCGDP","LIFEEX","bla")))
   expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = c("PCGDP","LIFEEX","bla")))
 
@@ -1294,8 +1294,8 @@ test_that("G.data.frame method with logdiff is foolproof", {
   expect_error(G(wlddev, 1,1,~iso3c, cols = NULL, logdiff = TRUE))
   expect_error(G(wlddev, 1,1,wlddev$iso3c, wlddev$year, cols = NULL, logdiff = TRUE))
   expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = NULL, logdiff = TRUE))
-  expect_error(G(wlddev, cols = 9:13, logdiff = TRUE))
-  expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = 9:13, logdiff = TRUE))
+  expect_error(G(wlddev, cols = 9:14, logdiff = TRUE))
+  expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = 9:14, logdiff = TRUE))
   expect_error(G(wlddev, cols = c("PCGDP","LIFEEX","bla"), logdiff = TRUE))
   expect_error(G(wlddev, 1,1,~iso3c, ~year, cols = c("PCGDP","LIFEEX","bla"), logdiff = TRUE))
 
